==> react-bootstrap-0.2.0.tgz: package/es/components/Form/index.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp2;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';

import Label from './Label';
import Group from './Group';
import Text from './Text';

var Form = (_temp2 = _class = function (_Component) {
  _inherits(Form, _Component);

  function Form() {
    var _temp, _this, _ret;

    _classCallCheck(this, Form);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = _possibleConstructorReturn(this, _Component.call.apply(_Component, [this].concat(args))), _this), _this.handleSubmit = function (e) {
      e.preventDefault();
      _this.props.onSubmit(e);
    }, _temp), _possibleConstructorReturn(_this, _ret);
  }

  Form.prototype.render = function render() {
    var _props = this.props,
        onSubmit = _props.onSubmit,
        children = _props.children,
        props = _objectWithoutProperties(_props, ['onSubmit', 'children']);

    return React.createElement(
      'form',
      _extends({}, props, { onSubmit: this.handleSubmit }),
      children
    );
  };

  return Form;
}(Component), _class.defaultProps = {
  onSubmit: function onSubmit() {},
  children: null
}, _class.Label = Label, _class.Group = Group, _class.Text = Text, _temp2);
Form.propTypes = process.env.NODE_ENV !== "production" ? {
  onSubmit: PropTypes.func,
  children: PropTypes.node
} : {};


export default Form;

==> react-bootstrap-0.3.0.tgz: package/es/components/Form/index.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp2;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';

import createComponent from '../../utils/createComponent';

var Group = createComponent('Form.Group', 'form-group');
// eslint-disable-next-line
var Label = function Label(props) {
  return React.createElement('label', props);
};
var Text = createComponent('Form.Text', 'form-text');

var Form = (_temp2 = _class = function (_Component) {
  _inherits(Form, _Component);

  function Form() {
    var _temp, _this, _ret;

    _classCallCheck(this, Form);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = _possibleConstructorReturn(this, _Component.call.apply(_Component, [this].concat(args))), _this), _this.handleSubmit = function (e) {
      e.preventDefault();
      _this.props.onSubmit(e);
    }, _temp), _possibleConstructorReturn(_this, _ret);
  }

  Form.prototype.render = function render() {
    var _props = this.props,
        onSubmit = _props.onSubmit,
        props = _objectWithoutProperties(_props, ['onSubmit']);

    return React.createElement('form', _extends({ onSubmit: this.handleSubmit }, props));
  };

  return Form;
}(Component), _class.defaultProps = {
  onSubmit: function onSubmit() {}
}, _class.Group = Group, _class.Label = Label, _class.Text = Text, _temp2);
Form.propTypes = process.env.NODE_ENV !== "production" ? {
  onSubmit: PropTypes.func
} : {};


export default Form;
